using UnityEngine;
using System.IO;
using GuidewireSim;

public class CreationScript : MonoBehaviour
{
    private string logFilePath = "";    
    public GameObject spherePrefab; //This is for choosing a Prefab for the sphere element. One can directly gain this in Robins code from: Assets/Guidewire_Assets/Prefabs
    public GameObject cylinderPrefab; //This is for choosing a Prefab for the cylinder element. One can directly gain this in Robins code from: Assets/Guidewire_Assets/Prefabs
    private int spheresCount; //This variable is used to store the number of spheres in the guidewire, so the script can keep knowledge on how many spheres were created
    private GameObject[] spheres; //This array is used to store references to the sphere game objects in the guidewire. //This array is used to store references to the sphere game objects in the guidewire. 
    private GameObject[] cylinders; //-''- 
    private SimulationLoop simulationLoop;

    void Start()
    {
        simulationLoop = GameObject.Find("Simulation").GetComponent<SimulationLoop>();
        InvokeRepeating("SavePositionsToFile", 0f, 1f);
    }

    private void Awake()
    {
        string[] args = System.Environment.GetCommandLineArgs();
        for (int i = 0; i < args.Length; i++)
        {
            if (args[i] == "-logFilePath" && args.Length > i + 1)
            {
                logFilePath = args[i + 1];
            }
        }
    }

    void FixedUpdate()
    {
        //SavePositionsToFile();
    }
//This code segment is responsible for creating and positioning the spheres and cylinders 
    public void CreateGuidewire(int numberElements)
    {
        spheres = new GameObject[numberElements];
        cylinders = new GameObject[numberElements - 1];
        //Here we use GetComponent to recieve the value of the variable rodElementLength that is stored in the SimulationLoop script. As this variable needs to be private, we use a getter Method and therefore also call this instead of calling the variable directly.
        float rEL = simulationLoop.GetRodElementLength();

        for (int i = 0; i < numberElements; ++i)
        {
            GameObject sphere = Instantiate(spherePrefab);
            sphere.transform.position = new Vector3(0, 0, -2000 + i * rEL);
            sphere.transform.parent = this.transform;

            spheres[i] = sphere;

            if (i < numberElements - 1)
            {
                GameObject cylinder = Instantiate(cylinderPrefab);
                cylinder.layer = 6;
                cylinder.transform.parent = this.transform;

                cylinders[i] = cylinder;
            }
        }

        spheresCount = numberElements;

        simulationLoop.SetSpheres(spheres);
        simulationLoop.SetCylinders(cylinders);
    }
     //Here I save the positions of the spheres to a .txt file. The file path has to be adapted to the local network for the file one wants to save the positons to
    public void SavePositionsToFile()
    {
        using (StreamWriter writer = new StreamWriter(logFilePath, true))
        {
            if (spheres != null && spheres.Length > 0)
            {
                Vector3 firstSpherePosition = spheres[0].transform.position;
                writer.WriteLine("First Sphere: " + firstSpherePosition.x + "," + firstSpherePosition.y + "," + firstSpherePosition.z);

                if (spheres.Length > 1)
                {
                    Vector3 lastSpherePosition = spheres[spheres.Length - 1].transform.position;
                    writer.WriteLine("Last Sphere: " + lastSpherePosition.x + "," + lastSpherePosition.y + "," + lastSpherePosition.z);
                }
            }
        }
    }

    

    public GameObject GetLastSphere()
    {
        if (spheres != null && spheres.Length > 0)
        {
            return spheres[spheres.Length - 1];
        }
        return null;
    }

    public GameObject[] GetSpheres()
    {
        return spheres;
    }

    public GameObject[] GetCylinders()
    {
        return cylinders;
    }
}
